"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getPlural = getPlural;
exports.getAllPlurals = getAllPlurals;

var _pluralCategories = _interopRequireDefault(require("make-plural/umd/pluralCategories"));

var _plurals = _interopRequireDefault(require("make-plural/umd/plurals"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @class
 * @private
 * @hideconstructor
 * @classdesc Utility getter/wrapper for pluralization functions from
 * {@link http://github.com/eemeli/make-plural.js make-plural}
 */
function wrapPluralFunc(lc, pf, noPluralKeyChecks) {
  var fn = function () {
    return pf.apply(this, arguments);
  };

  fn.toString = () => pf.toString();

  if (noPluralKeyChecks) {
    fn.cardinal = [];
    fn.ordinal = [];
  } else {
    const pc = _pluralCategories.default[lc] || {};
    fn.cardinal = pc.cardinal;
    fn.ordinal = pc.ordinal;
  }

  return fn;
}

function getPlural(locale, noPluralKeyChecks) {
  for (let lc = String(locale); lc; lc = lc.replace(/[-_]?[^-_]*$/, '')) {
    const pf = _plurals.default[lc];
    if (pf) return wrapPluralFunc(lc, pf, noPluralKeyChecks);
  }

  throw new Error('Localisation function not found for locale ' + JSON.stringify(locale));
}

function getAllPlurals(noPluralKeyChecks) {
  const locales = {};
  const keys = Object.keys(_plurals.default);

  for (let i = 0; i < keys.length; ++i) {
    const lc = keys[i];
    locales[lc] = wrapPluralFunc(lc, _plurals.default[lc], noPluralKeyChecks);
  }

  return locales;
}